
*ORIGINAL DATA FROM http://www.ats.ucla.edu/stat/sas/dae/mvreg.htm;
OPTIONS NONUMBER NODATE NOCENTER PAGESIZE=MAX LINESIZE=120 formdlim='-';
* Kill default titles on output;
TITLE;

ODS LISTING;

%LET DATAPATH = C:\Users\jtemplin2\Desktop\Example Data;
/***********************************************************************************************************************************************
						Multivariate Analysis by Group
						   A Story from High School
In order to study the effects of several psychological variables on academic performance, 
a researcher has collected data on three psychological variables (each reported as a z-score): 

1.	The Duttweiler Internal Control Index measuring locus of control.
2.	The High School Self Concept Scale.
3.	The Motivation to Achieve Scale for High School Students
.
Data were collected on the type of educational program the student was enrolled in at the time: 
general education, science and technical, or vocational.

Finally, the researcher collected three academic variables (standardized test scores):

1.	Reading
2.	Writing
3.	Science

In a general sense, the researcher wanted to know how psychological variables and program choice 
impacted general performance in high school. 

Your task  help him or her to decide what questions can be answered by the research d
esign...then implement these analyses to provide results to the researcher.

***********************************************************************************************************************************************/

LIBNAME example "&DATAPATH.";

PROC MEANS DATA=example.hsdata_wide MEAN MAX MIN;
VAR LOCUS_OF_CONTROL SELF_CONCEPT MOTIVATION;
OUTPUT OUT=example.ivmeans MEAN(LOCUS_OF_CONTROL)=mean_LOC MEAN(SELF_CONCEPT)=mean_SC MEAN(MOTIVATION)=mean_M;
RUN;

PROC FORMAT;
	VALUE programtype 
		1 = "General"
		2 = "Technical"
		3 = "Vocational";
RUN;


*Convert from wide to stacked data;
DATA example.hsdata_stacked;
	SET example.hsdata_wide;
	
	FORMAT prog programtype.;

	*FOR READING;
	testscore = read;
	testtype = "Reading Score";
	OUTPUT;

	*FOR WRITING;
	testscore = write;
	testtype = "Writing Score";
	OUTPUT;

	*FOR SCIENCE;
	testscore = science;
	testtype = "Science Score";
	OUTPUT;

RUN;

*INITIAL MODEL SETUP: AN EMPTY MODEL IN PROC MIXED;
PROC MIXED DATA=example.hsdata_stacked METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS testtype ;
MODEL testscore = testtype / S DDFM=KENWARDROGER;
REPEATED / SUBJECT = STUDENT_ID TYPE=UN R RCORR;
RUN;
